from paste.script.templates import var

from base import BaseTemplate

class Middleware(BaseTemplate):
    summary = "A template for WSGI filters"
    _template_dir = "templates/middleware"
    required_templates = 'wsgi_package',

    entrypoint_type = "paste.filter_factory"

    vars = [
        var('entrypointname', 'The name of the middleware filter being created.' 
                              ' (lowercase letters only, no special chars)'),
        ]




from paste.script import templates
from paste.script.templates import var
import os

class Package(templates.Template):
    summary = "A simple package with a buildout"
    _template_dir = "templates/package"

    
    use_cheetah = True
    
    def run(self, command, output_dir, vars):
        templates.Template.run(self, command, output_dir, vars)

    vars = [
        var('version', 'Version', default='1.0'),
        var('description', 'One-line description of the package'),
        var('long_description', 'Multi-line description (in reST)'),
        var('author', 'Author name'),
        var('author_email', 'Author email'),
        ]
    
    def pre(self, command, output_dir, vars):
        vars['segs'] = vars['egg'].split('.')
        namespace =[]
        
        for i in range(len(vars['segs'])-1):
            namespace.append(".".join(vars['segs'][0:i+1]))
        
        vars['namespace'] = namespace
        
        super(Package, self).pre(command, output_dir, vars)
    
    def post(self, command, output_dir, vars):
        cwd = os.getcwd()
        os.chdir(os.path.join(vars['egg'], 'src'))
        for i in range(len(vars['segs'])):
            segs = vars['segs'][0:i+1]
            try:
                os.mkdir(os.path.join(*vars['segs'][0:i+1]))
            except OSError:
                pass
            segs.append("__init__.py")
            init = open(os.path.join(*segs), "w")
            if i == len(vars['segs'])-1:
                segs[-1] = "README.txt"
                open(os.path.join(*segs), "w").close()
            else:
                init.write("__import__('pkg_resources').declare_namespace(__name__)")
            init.close()
        os.chdir(cwd)
        super(Package, self).post(command, output_dir, vars)


from paste.script.templates import var

from base import BaseTemplate

class Composite(BaseTemplate):
    summary = "A template for WSGI composites"
    _template_dir = "templates/composite"
    required_templates = 'wsgi_package',
    
    entrypoint_type = "paste.composite_factory"

    vars = [
        var('entrypointname', 'The name of the composite being created.' 
                              ' (lowercase letters only, no special chars)'),
        ]

    



from paste.script.templates import var

from base import BaseTemplate

class Endpoint(BaseTemplate):
    summary = "A template for WSGI applications"
    _template_dir = "templates/endpoint"
    required_templates = 'wsgi_package',

    entrypoint_type = "paste.app_factory"
        
    vars = [
        var('entrypointname', 'The name of the application being created.' 
                              ' (lowercase letters only, no special chars)'),
        ]




from wsgitemplates.middleware_template import Middleware
from wsgitemplates.composite_template import Composite
from wsgitemplates.endpoint_template import Endpoint as EndPoint
from wsgitemplates.package import Package


from setuptools import setup, find_packages
import sys, os

version = '0.1'

setup(name='wsgitemplates',
      version=version,
      description="A series of templates for use in creating WSGI applications",
      long_description="""\
""",
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='wsgi template paste',
      author='Matthew Wilkes',
      author_email='matt@matthewwilkes.name',
      url='http://code.google.com/p/wsgitemplates',
      license='BSD',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
        'PasteScript',
        'Cheetah>=1.0',
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      [paste.paster_create_template]
      wsgi_package = wsgitemplates:Package

      wsgi_filter = wsgitemplates:Middleware
      wsgi_composite = wsgitemplates:Composite
      wsgi_application = wsgitemplates:EndPoint
      """,
      )



import os

from paste.script import templates

class BaseTemplate(templates.Template):
    """A basetemplate for creating WSGI applications"""
    
    use_cheetah = True
    
    def run(self, command, output_dir, vars):
        original_output_dir = output_dir
        output_dir = os.path.join(*([vars['egg'], 'src'] + vars['segs']))
        self.pre(command, output_dir, vars)
        self.write_files(command, output_dir, vars)
        self.post(command, original_output_dir, vars)

    def check_vars(self, vars, _):
        vars['type'] = self.entrypoint_type
        vars = templates.Template.check_vars(self, vars, _)
        return vars

    def post(self, command, output_dir, vars):
        setuppy = open(os.path.join(output_dir, "setup.py"), "r")
        s = setuppy.read()
        setuppy.close()

        s = s.replace("# -*- Entry points: -*-", self.getEntrypoints(vars))

        setuppy = open(os.path.join(output_dir, "setup.py"), "w")
        s = setuppy.write(s)
        setuppy.close()

        templates.Template.post(self, command, output_dir, vars)

    def getEntrypoints(self, vars):
        entrypoints = "# -*- Entry points: -*-\n"
        entrypoints += "[%s]\n%s = %s.%s:%s" % (self.entrypoint_type,
                                     vars['entrypointname'],
                                     vars['egg'],
                                     vars['entrypointname'],
                                     vars['entrypointname'].title()+'Factory')
        return entrypoints
